#!/bin/bash

# Versi 7/12/2012 20:10.

# Dades de partida:
#    El genoma est a ../Latimeria_chalumnae/genome.fa
#    Les selenoproteines, en el nostre treball sn 30, estan a ./selenoproteines

# Comencem afegint els paths amb els que treballarem
export PATH=/cursos/BI/bin/ncbiblast/bin:$PATH            # pel NCBI Blast
cp /cursos/BI/bin/ncbiblast/.ncbirc ~/                    # pel NCBI Blast
export PATH=/cursos/BI/soft/exonerate/i386/bin:$PATH      # per l'exonerate
export PATH=/cursos/BI/bin:$PATH                          # pel genewise, el fastaseqfromGFF.pl i el t_coffee
export WISECONFIGDIR=/cursos/BI/soft/wise-2.2.0/wisecfg   # Linking to GeneWise: Set the WISECONFIGDIR variable to point to the wisecfg subdirectory.

rm acumula_resultats.tmp   # Fem neteja d'un possible anterior resultat ja que utilitzem >>

# Fem un bucle per a totes les selenoproteines que hi hagin a la carpeta /selenoproteines
#    La variable query contindr noms el nom de cada selenoproteina

for query in selenoproteines/* ;
do {
   query=`basename $query`
   query=${query%.fa}     # Eliminem el ".fa" del nom de l'arxiu de la selenoproteina
   echo Selenoproteina actual es $query .
   mkdir $query.carpeta   # Creem una carpeta per cada selenoproteina amb el seu nom.carpeta on emmagatzemem a cada pas els resultats obtinguts.
   # Trobem els hits, s a dir a on la selenoproteina pot trobar-se en el genoma amb una certa probabilitat
   blastall -p tblastn -m9 -i selenoproteines/$query.fa -d ../Latimeria_chalumnae/genome.fa -o $query.carpeta/blast

   # Seleccionem el hit, un de sol, a on la selenoproteina es pot trobar amb major probabilitat
   # Fins ara sempre el 1r scaffold de l'arxiu blast s el de major probabilitat per ho verifiquem.
   
   # El 1r egrep ignora les lnies que comencen amb #
   # El 2n egrep selecciona la 1a lnia amb el text 'e-' ja que els evalues que continguin 'e-' sn els hits significatius.
   # L'awk selecciona el 2n valor de la taula que s el SubjectID
   # Guardem en un nou arxiu temporal de nom blast.evalues noms els SubjectID i els evalue
   egrep -v '#' $query.carpeta/blast | egrep 'e-' | awk '{print $2 "\t" $11}' > $query.carpeta/blast.evalues

   # buscarem el mnim evalue de l'arxiu amb l'ajuda d'un programa que hem escrit en Perl
   ./minim_evalue.pl $query.carpeta/blast.evalues
   
   # La variable SubjectID contindr l'identificador de l'scaffold de l'arxiu blast   
   SubjectID=`more evaluebuscat.tmp`

   echo $SubjectID $query >> acumula_resultats.tmp    # Anem guardant el resultats per l'informe final en qu veurem a quin scaffold es troba cada protena
      
   # Tallem l'scaffold trobat en el pas anterior del genoma (DNA)
   fastafetch /homes/users/U65972/Latimeria_chalumnae/genome.fa /homes/users/U65972/Latimeria_chalumnae/genome.index "$SubjectID" > $query.carpeta/genomic.fa
   
   # Exonerate s un blast per ms acurat
   exonerate -m p2g --showtargetgff -q selenoproteines/$query.fa -t $query.carpeta/genomic.fa > $query.carpeta/exonerate.gff
   
   # Extreiem els exons del resultat de l'exonerate anterior
   egrep -w exon $query.carpeta/exonerate.gff  > $query.carpeta/exonerateexons.gff
   
   # Passem de fitxer .gff a .fa (DNA)
   fastaseqfromGFF.pl $query.carpeta/genomic.fa $query.carpeta/exonerateexons.gff > $query.carpeta/fastaseqfromGFF.fa

   # Passem de DNA a proteina

   fastatranslate $query.carpeta/fastaseqfromGFF.fa -F 1 > $query.carpeta/fastatranslateF1.fa
   # Comparem proteina amb proteina

   t_coffee $query.carpeta/fastatranslateF1.fa selenoproteines/$query.fa > $query.carpeta/tcoffee.txt
   # Ho repetim tot per cada una de les selenoproteines
} done

sort acumula_resultats.tmp > resum_resultats.txt    # Fitxer final en que veurem una llista de les protenes i a quin scaffold es troben ordenat, per veure les coincidencies 